@@ -119,9 +119,9 @@ class IncludeNavLoader:
         return self.absNavPath
 
     def read(self):
-        if not self.absNavPath.endswith(".yml"):
+        if not self.absNavPath.endswith(tuple([".yml", ".yaml"])):
             log.critical(
-                "[mkdocs-monorepo] The included file path {} does not point to a .yml file".format(
+                "[mkdocs-monorepo] The included file path {} does not point to a .yml (or .yaml) file".format(
                     self.absNavPath)
             )
             raise SystemExit(1)
